;;; cmail-use-simap4.el --- use simap4 to access email

;; Author: Takeshi Morishima (tm@interaccess.com)
;; Keywords: mail
;; Created at: Sat Feb 26 15:39:56 JST 2000

;; This file is part of cmail (a mail utility for GNU Emacs)

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or (at
;; your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;; This is a cmail option feature module for simap4.el.

;;; Code:

(require 'path-util)
(require 'cmail-vars)
(require 'cmail-modes)

(cmail-i18n-defgroup cmail-simap4-group nil
  ((ja_JP . "simap4.el$B$rMxMQ$7$F(BIMAP4$B%5!<%P$K%"%/%;%9$9$k$?$a$N@_Dj!#(B")
   (en_US . "Customization for accessing mail servers using simap4.el."))
  :group 'cmail-other-features)

(defun cmail-set-simap4 (var flag)
  (set var flag)
  (if flag (cmail-use-simap4-setup)
    (cmail-use-simap4-unsetup)))

(defun cmail-use-simap4-setup ()

  (setq cmail-content-supply-function 'cmail-simap4-supply-body)
  (autoload 'cmail-simap4-supply-body "cmail-simap4")

  (setq cmail-message-copy-function 'cmail-simap4-copy-message)
  (autoload 'cmail-simap4-copy-body "cmail-simap4")

  (setq cmail-message-delete-function 'cmail-simap4-delete-message)
  (autoload 'cmail-simap4-delete-message "cmail-simap4")

  (setq cmail-message-mark-function 'cmail-simap4-mark-message)
  (autoload 'cmail-simap4-mark-message "cmail-simap4")

  (setq cmail-message-status-function 'cmail-simap4-message-status)
  (autoload 'cmail-simap4-message-status "cmail-simap4")

  (setq cmail-message-expunge-function 'cmail-simap4-expunge-messages)
  (autoload 'cmail-simap4-expunge-messages "cmail-simap4")

  (setq cmail-mailbox-open-function 'cmail-simap4-open-mailbox)
  (autoload 'cmail-simap4-open-mailbox "cmail-simap4")

  (setq cmail-mailbox-delete-function 'cmail-simap4-delete-mailbox)
  (autoload 'cmail-simap4-delete-mailbox "cmail-simap4")

  (setq cmail-mailbox-rename-function 'cmail-simap4-rename-mailbox)
  (autoload 'cmail-simap4-rename-mailbox "cmail-simap4")

  (setq cmail-mailbox-copy-function 'cmail-simap4-copy-mailbox)
  (autoload 'cmail-simap4-copy-mailbox "cmail-simap4")

  (setq cmail-mailbox-search-function 'cmail-simap4-search-mailbox)
  (autoload 'cmail-simap4-search-mailbox "cmail-simap4")

  (setq cmail-folders-update-function 'cmail-simap4-sync-folders)
  (autoload 'cmail-simap4-sync-folders "cmail-simap4")

  (setq cmail-folders-search-function 'cmail-simap4-search-folders)
  (autoload 'cmail-simap4-search-folders "cmail-simap4")

  (setq cmail-summary-message-fetch-function 'cmail-simap4-get-new-messages)
  (autoload 'cmail-simap4-sync-folders "cmail-simap4")

  (define-key cmail-summary-mode-map "\C-c " 'cmail-simap4-force-read-content)
  (autoload 'cmail-simap4-force-read-content "cmail-simap4" "" t)
  (define-key cmail-summary-mode-map "G" 'cmail-simap4-sync-folder)
  (autoload 'cmail-simap4-sync-folder "cmail-simap4" "" t)
  (define-key cmail-folders-mode-map "G" 'cmail-simap4-sync-all-folders)
  (autoload 'cmail-simap4-sync-all-folder "cmail-simap4" "" t))

(defun cmail-use-simap4-unsetup ()
  (setq cmail-content-supply-function nil)
  (setq cmail-message-copy-function nil)
  (setq cmail-message-delete-function nil)
  (setq cmail-message-mark-function nil)
  (setq cmail-message-status-function nil)
  (setq cmail-message-expunge-function nil)
  (setq cmail-mailbox-open-function nil)
  (setq cmail-mailbox-delete-function nil)
  (setq cmail-mailbox-rename-function nil)
  (setq cmail-mailbox-copy-function nil)
  (setq cmail-mailbox-search-function nil)
  (setq cmail-folders-update-function nil)
  (setq cmail-folders-search-function nil)
  (setq cmail-summary-message-fetch-function nil)
  (if (featurep 'cmail-simap4) (unload-feature 'cmail-simap4)))

(cmail-i18n-defcustom cmail-use-simap4 nil
  ((ja_JP . "\
*Non nil $B$J$i$P(B simap4.el $B$rMxMQ$7$F(B IMAP4 $B%5!<%P$K%"%/%;%9$9$k!#(B")
   (en_US . "\
*Non nil means use simap4.el to access IMAP4 servers."))
  :type 'boolean
  :set 'cmail-set-simap4
  :group 'cmail-all-variables
  :group 'cmail-simap4-group)
(cmail-custom-add-init 'cmail-set-simap4 'cmail-use-simap4)

(cmail-i18n-defcustom cmail-simap4-servers nil
  ((ja_JP . "\
*Simple IMAP4 $BMQ$N%5!<%P@_Dj!#(B

$B3F%U%#!<%k%I$O<!$N0UL#$K$J$j$^$9!#(B

Record Format: $B%l%3!<%I$N%U%)!<%^%C%H%P!<%8%g%s!#JQ99$G$-$^$;$s!#(B
Record State: $B$3$N%5!<%P$K@\B3$7$?$/$J$$>l9g(B inactive $B$K$7$^$9!#(B
Server: IMAP4 $B%5!<%PL>!#(B
UserID: IMAP4 $B%5!<%P$K%m%0%$%s$9$k;~$N%f!<%6<1JLJ8;zNs!#(B
TopDir: $B%m!<%+%k%[%9%H>e$N%G%#%l%/%H%j!#(Bcmail-path $B$+$iAjBP%Q%9!#(B
        $B@_Dj$5$l$F$$$J$1$l$P%f!<%6(BID@$B%5!<%PL>$,%G%#%l%/%H%j$H$J(B
        $B$j$^$9!#(B
Virtual Folder: $B%m!<%+%k%[%9%H>e$G2>A[%U%)%k%@$r;HMQ$9$k$+!#2>(B
        $BA[%U%)%k%@$@$H!"(Bcmail $B=*N;;~%@%&%s%m!<%I>pJs$O>C$($F$7(B
        $B$^$$$^$9!#(B($B$^$@%5%]!<%H$7$F$^$;$s!#(B)
Mailboxes to Hide: $B%U%)%k%@F14|$GL5;k$9$k(B mailbox $BL>$NJ8;zNs!#(B
        \"regexp: \" $B$G;O$^$k>l9g@55,I=8=$H$_$J$5$l$^$9!#(B
DraftMbox: $B%I%i%U%H$rJ]B8$9$k(B mailbox $BL>$NJ8;zNs!#(B($B$^$@%5%]!<%H(B
        $B$7$F$^$;$s!#(B)
CFfile: $B$3$N%5!<%P@lMQ$N<+F0J,N`%k!<%k$J$I$rJ]B8$9$k%U%!%$%kL>!#(B
        ($B$^$@%5%]!<%H$7$F$^$;$s!#(B)")
   (en_US . "\
*Server configuration for Simple IMAP4.

Each field has the following meaning.

Record Format: Version of the format of this variable. Cannot be modified.
Record State: Set to inactive to exculde this server from the active list.
Server: IMAP4 server name for this account.
UserID: IMAP4 user identification string on this server for this account.
TopDir: Local host directory for this account, which is a relative path
        from cmail-path. If this is set to an empty string,
        userid@servername will be used.
Virtual Folder: Whether or not local folders should be virtual folders
        to make them completely volatile. If virtual folders are used,
        when exiting cmail, all downloaded information during the session
        will be discarded, and complete synchronization would be done at
        the time of next access. (Not yet supported.)
Mailboxes to Hide: A list of mailbox names which should be ignored when
        synchronizing the folders. A string starting with \"regexp: \"
        is considered as regular expression.
DraftMbox:  A name of IMAP4 mailbox, which is used to store draft
        messages. (Not yet supported.)
CFfile: A file name to save configuration such as auto refile rules
        specific to this account. (Not yet supported.)"))
  :type '(repeat
	  (list
	   (const :tag "Record Format: 1.0" "1.0")
	   (choice :tag "Record State"
		   (const :tag "Record active" nil)
		   (const :tag "Record inactive" t))
	   (string :tag "Server")
	   (string :tag "UserID")
	   (string :tag "TopDir")
	   (choice :tag "Virtual Folder"
		   (const :tag "Don't use virtual folder" nil)
		   (const :tag "Use virtual folder" t))
	   (repeat :tag "Mailboxes to Hide" (string))
	   (string :tag "DraftMbox")
	   (string :tag "CFfile")))
  :group 'cmail-all-variables
  :group 'cmail-simap4-group)

(cmail-i18n-defcustom cmail-simap4-fetch-mode 'headers-only
  ((ja_JP . "\
*$B:G=i$N%a%C%;!<%8<h$j9~$_;~$K$I$l$@$1$N>pJs$r<h$j9~$`$+!#(B

$B8=:_$O<!$N%b!<%I$,B8:_$9$k!#(B

   $B%X%C%@$N$_(B (headers-only): $B%X%C%@$@$1<h$j9~$s$G$*$$$F<+F0%"!<%+%$%V(B
$BEy$r9T$&!#K\J8$OI=<(;~$K<h$j9~$^$l$k!#9bB.@~$G$N>o;~@\B3$GI=<(;~$N%@%&(B
$B%s%m!<%I$,%9%H%l%9$K$J$i$J$$>l9g!"$^$?$OBgNL$N%a!<%k$rFI$^$:$K%?%$%H%k(B
$B$GA*Br$9$k>l9gEy$rA[Dj$7$F$$$k!#(B

   $B0lIt%@%&%s%m!<%I(B (partial-download): $B4pK\E*$K(B 7bit $B$N(B Text/plain $B$N(B
$B$_$r%@%&%s%m!<%I$7$FE:IU%U%!%$%k$J$I$r%@%&%s%m!<%I$7$J$$!#DcB.2s@~7PM3(B
$B$G$[$H$s$I$N$N%a!<%k$r<h$j9~$s$G$*$$$F%*%U%i%$%s:n6H$9$k>l9g$rA[Dj$7$F(B
$B$$$k!#A4%@%&%s%m!<%I$O%5%^%j%b!<%I$+$i%3%^%s%I$G<B9T$G$-$k!#(B

   $BA4%@%&%s%m!<%I(B(full-download): $BE:IU%U%!%$%k$J$I$r4^$a$?K\J8A4$F$r%@(B
$B%&%s%m!<%I$9$k!#E:IU%U%!%$%k$,$=$l$[$IL5$$$+!"9bB.2s@~$GA4%@%&%s%m!<%I(B
$B$,$=$l$[$I%9%H%l%9$K$J$i$J$$>l9g$G%*%U%i%$%s:n6H$N$?$a$K%a!<%k$r%m!<%+(B
$B%k$K%@%&%s%m!<%I$9$k>l9g$rA[Dj$7$F$$$k!#(B")

   (en_US . "\

*Specifies how the messages should be downloaded for the 1st fetch.

A choice of the following.

    Headers Only: Download message headers for quick view and
auto-archiving. The message body will be download when displayed. This
may be used when the server is always connected and accessed through a
high bandwidth network, and does not cause too much trouble to
download body on the fly.

    Partial Download: Download parts of a message, mainly mime part of
text/Plain with 7bit transfer encoding, and will not download large
attachments. This may be used when the server is not always connected
and/or connected through a low bandwidth line, and you would like to
look at all the messages off-line anyway. Full download can be
performed from the summary mode if needed manually.

    Full Download: Download whole message including all the attachment
files. This may be used when you do not normally receive messages with
large attatchments, or the server is accessed through very high
bandwidth network and you do not care to download everything. (Or when
you have no chice because you need the attachments for off-line
meeting etc.)"))
  :type '(choice (const :tag "Headers only" headers-only)
		 (const :tag "Partial Download" partial-download)
		 (const :tag "Full Download" full-download))
  :group 'cmail-all-variables
  :group 'cmail-simap4-group)

(cmail-i18n-defcustom cmail-simap4-max-msg-size 20000
  ((ja_JP . "\
*$B%a%C%;!<%8$N%@%&%s%m!<%I$r@)8B$9$k$?$a$K;HMQ$5$l$k>e8B%5%$%:!#(B")
   (en_US . "\
*Message size used to determine whether to download message."))
  :type 'integer
  :group 'cmail-all-variables
  :group 'cmail-simap4-group)

(cmail-i18n-defcustom cmail-simap4-max-body-size 2000
  ((ja_JP . "\
*$B%a%C%;!<%8%Q!<%H$N%@%&%s%m!<%I$r@)8B$9$k$?$a$K;HMQ$5$l$k>e8B%5%$%:!#(B")
   (en_US . "\
*Message part size used to determine whether to download part."))
  :type 'integer
  :group 'cmail-all-variables
  :group 'cmail-simap4-group)

(cmail-i18n-defcustom cmail-simap4-connection-timeout 60
  ((ja_JP . "\
*$B%5!<%P$K@\B3$9$k;~$N%?%$%`%"%&%HCM(B($BIC(B)")
   (en_US . "\
*Timeout value in seconds used when opening a server connection."))
  :type 'integer
  :group 'cmail-all-variables
  :group 'cmail-simap4-group)

(cmail-i18n-defcustom cmail-simap4-command-timeout 20
  ((ja_JP . "\
*$B%5!<%P$N1~Ez$rBT$D;~$N%?%$%`%"%&%HCM(B($BIC(B)")
   (en_US . "\
*Timeout value in seconds used when waiting for a server response."))
  :type 'integer
  :group 'cmail-all-variables
  :group 'cmail-simap4-group)

(defun cmail-use-simap4 nil)
(provide 'cmail-use-simap4)

;; end-of-file
